@@ -19,7 +19,7 @@ class TeamCreate(TeamBase):
     pass
 
 
-class TeamRead(TeamBase):
+class TeamPublic(TeamBase):
     id: int
 
 
@@ -42,7 +42,7 @@ class Hero(HeroBase, table=True):
     team: Optional[Team] = Relationship(back_populates="heroes")
 
 
-class HeroRead(HeroBase):
+class HeroPublic(HeroBase):
     id: int
 
 
@@ -81,27 +81,27 @@ def on_startup():
     create_db_and_tables()
 
 
-@app.post("/heroes/", response_model=HeroRead)
+@app.post("/heroes/", response_model=HeroPublic)
 def create_hero(*, session: Session = Depends(get_session), hero: HeroCreate):
-    db_hero = Hero.from_orm(hero)
+    db_hero = Hero.model_validate(hero)
     session.add(db_hero)
     session.commit()
     session.refresh(db_hero)
     return db_hero
 
 
-@app.get("/heroes/", response_model=List[HeroRead])
+@app.get("/heroes/", response_model=List[HeroPublic])
 def read_heroes(
     *,
     session: Session = Depends(get_session),
     offset: int = 0,
-    limit: int = Query(default=100, lte=100),
+    limit: int = Query(default=100, le=100),
 ):
     heroes = session.exec(select(Hero).offset(offset).limit(limit)).all()
     return heroes
 
 
-@app.get("/heroes/{hero_id}", response_model=HeroRead)
+@app.get("/heroes/{hero_id}", response_model=HeroPublic)
 def read_hero(*, session: Session = Depends(get_session), hero_id: int):
     hero = session.get(Hero, hero_id)
     if not hero:
@@ -109,14 +109,14 @@ def read_hero(*, session: Session = Depends(get_session), hero_id: int):
     return hero
 
 
-@app.patch("/heroes/{hero_id}", response_model=HeroRead)
+@app.patch("/heroes/{hero_id}", response_model=HeroPublic)
 def update_hero(
     *, session: Session = Depends(get_session), hero_id: int, hero: HeroUpdate
 ):
     db_hero = session.get(Hero, hero_id)
     if not db_hero:
         raise HTTPException(status_code=404, detail="Hero not found")
-    hero_data = hero.dict(exclude_unset=True)
+    hero_data = hero.model_dump(exclude_unset=True)
     for key, value in hero_data.items():
         setattr(db_hero, key, value)
     session.add(db_hero)
@@ -127,7 +127,6 @@ def update_hero(
 
 @app.delete("/heroes/{hero_id}")
 def delete_hero(*, session: Session = Depends(get_session), hero_id: int):
-
     hero = session.get(Hero, hero_id)
     if not hero:
         raise HTTPException(status_code=404, detail="Hero not found")
@@ -136,27 +135,27 @@ def delete_hero(*, session: Session = Depends(get_session), hero_id: int):
     return {"ok": True}
 
 
-@app.post("/teams/", response_model=TeamRead)
+@app.post("/teams/", response_model=TeamPublic)
 def create_team(*, session: Session = Depends(get_session), team: TeamCreate):
-    db_team = Team.from_orm(team)
+    db_team = Team.model_validate(team)
     session.add(db_team)
     session.commit()
     session.refresh(db_team)
     return db_team
 
 
-@app.get("/teams/", response_model=List[TeamRead])
+@app.get("/teams/", response_model=List[TeamPublic])
 def read_teams(
     *,
     session: Session = Depends(get_session),
     offset: int = 0,
-    limit: int = Query(default=100, lte=100),
+    limit: int = Query(default=100, le=100),
 ):
     teams = session.exec(select(Team).offset(offset).limit(limit)).all()
     return teams
 
 
-@app.get("/teams/{team_id}", response_model=TeamRead)
+@app.get("/teams/{team_id}", response_model=TeamPublic)
 def read_team(*, team_id: int, session: Session = Depends(get_session)):
     team = session.get(Team, team_id)
     if not team:
@@ -164,7 +163,7 @@ def read_team(*, team_id: int, session: Session = Depends(get_session)):
     return team
 
 
-@app.patch("/teams/{team_id}", response_model=TeamRead)
+@app.patch("/teams/{team_id}", response_model=TeamPublic)
 def update_team(
     *,
     session: Session = Depends(get_session),
@@ -174,7 +173,7 @@ def update_team(
     db_team = session.get(Team, team_id)
     if not db_team:
         raise HTTPException(status_code=404, detail="Team not found")
-    team_data = team.dict(exclude_unset=True)
+    team_data = team.model_dump(exclude_unset=True)
     for key, value in team_data.items():
         setattr(db_team, key, value)
     session.add(db_team)
