@@ -5,5 +5,5 @@ set -x
 
 coverage run -m pytest tests
 coverage combine
-coverage report --show-missing
+coverage report
 coverage html
